==> realestate-supervise-common-1.0.0-20210224.062454-42-sources.jar: cn/gtmap/realestate/supervise/entity/BaC.java <==
package cn.gtmap.realestate.supervise.entity;

import com.sun.istack.internal.Nullable;
import cn.gtmap.realestate.supervise.core.reflect.*;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description  层属性结构
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(name = "ba_c")
public class BaC implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    private String ch;

    @XmlAttribute
    private String zrzh;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    @Nullable
    private String sjc;

    @XmlAttribute
    @Nullable
    private String myc;

    @XmlAttribute
    @Nullable
    private String cjzmj;

    @XmlAttribute
    @Nullable
    private String ctnjzmj;

    @XmlAttribute
    @Nullable
    private String cytmj;

    @XmlAttribute
    @Nullable
    private String cgyjzmj;

    @XmlAttribute
    @Nullable
    private String cftjzmj;

    @XmlAttribute
    @Nullable
    private String cbqmj;

    @XmlAttribute
    @Nullable
    private String cg;


    @XmlAttribute
    @Nullable
    private String sptymj;

    @XmlAttribute
    private String zrzbh;

    @XmlAttribute
    @Nullable
    @qxdm
    private String qxdm;

    @Nullable
    private Date sjgxsj;

    @ywh
    private String ywh;

    @bdcdyh
    private String bdcdyh;

    @bwmc
    private String bwmc;

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getCh() {
        return ch;
    }

    public String getZrzh() {
        return zrzh;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getSjc() {
        return sjc;
    }

    public String getMyc() {
        return myc;
    }

    public String getCjzmj() {
        return cjzmj;
    }

    public String getCtnjzmj() {
        return ctnjzmj;
    }

    public String getCytmj() {
        return cytmj;
    }

    public String getCgyjzmj() {
        return cgyjzmj;
    }

    public String getCftjzmj() {
        return cftjzmj;
    }

    public String getCbqmj() {
        return cbqmj;
    }

    public String getCg() {
        return cg;
    }

    public String getSptymj() {
        return sptymj;
    }

    public void setCh(String ch) {
        this.ch = ch;
    }

    public void setZrzh(String zrzh) {
        this.zrzh = zrzh;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setSjc(String sjc) {
        this.sjc = sjc;
    }

    public void setMyc(String myc) {
        this.myc = myc;
    }

    public void setCjzmj(String cjzmj) {
        this.cjzmj = cjzmj;
    }

    public void setCtnjzmj(String ctnjzmj) {
        this.ctnjzmj = ctnjzmj;
    }

    public void setCytmj(String cytmj) {
        this.cytmj = cytmj;
    }

    public void setCgyjzmj(String cgyjzmj) {
        this.cgyjzmj = cgyjzmj;
    }

    public void setCftjzmj(String cftjzmj) {
        this.cftjzmj = cftjzmj;
    }

    public void setCbqmj(String cbqmj) {
        this.cbqmj = cbqmj;
    }

    public void setCg(String cg) {
        this.cg = cg;
    }

    public void setSptymj(String sptymj) {
        this.sptymj = sptymj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getZrzbh() {
        return zrzbh;
    }

    public void setZrzbh(String zrzbh) {
        this.zrzbh = zrzbh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }
}

==> realestate-supervise-common-1.1.0-20250924.014108-69-sources.jar: cn/gtmap/realestate/supervise/entity/BaC.java <==
package cn.gtmap.realestate.supervise.entity;

import com.sun.istack.internal.Nullable;
import cn.gtmap.realestate.supervise.core.reflect.*;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description  层属性结构
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(name = "ba_c")
public class BaC implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    private String ch;

    @XmlAttribute
    private String zrzh;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    @Nullable
    private String sjc;

    @XmlAttribute
    @Nullable
    private String myc;

    @XmlAttribute
    @Nullable
    private String cgyjzmj;

    @XmlAttribute
    @Nullable
    private String cg;


    @XmlAttribute
    @Nullable
    private String sptymj;

    @XmlAttribute
    private String zrzbh;

    @XmlAttribute
    @Nullable
    @qxdm
    private String qxdm;

    @Nullable
    private Date sjgxsj;

    @ywh
    private String ywh;

    @bdcdyh
    private String bdcdyh;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String zrzbsm;

    @XmlAttribute
    private String ljzh;

    public String getZrzbsm() {
        return zrzbsm;
    }

    public void setZrzbsm(String zrzbsm) {
        this.zrzbsm = zrzbsm;
    }

    public String getLjzh() {
        return ljzh;
    }

    public void setLjzh(String ljzh) {
        this.ljzh = ljzh;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getCh() {
        return ch;
    }

    public String getZrzh() {
        return zrzh;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getSjc() {
        return sjc;
    }

    public String getMyc() {
        return myc;
    }

    public String getCgyjzmj() {
        return cgyjzmj;
    }

    public String getCg() {
        return cg;
    }

    public String getSptymj() {
        return sptymj;
    }

    public void setCh(String ch) {
        this.ch = ch;
    }

    public void setZrzh(String zrzh) {
        this.zrzh = zrzh;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setSjc(String sjc) {
        this.sjc = sjc;
    }

    public void setMyc(String myc) {
        this.myc = myc;
    }

    public void setCgyjzmj(String cgyjzmj) {
        this.cgyjzmj = cgyjzmj;
    }

    public void setCg(String cg) {
        this.cg = cg;
    }

    public void setSptymj(String sptymj) {
        this.sptymj = sptymj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getZrzbh() {
        return zrzbh;
    }

    public void setZrzbh(String zrzbh) {
        this.zrzbh = zrzbh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }
}
